@@ -1,59 +1,59 @@
 $VAR1 = {
-          'files' => {
-                       'owner' => 'lze',
-                       'chmod' => '0755',
-                       'group' => 'lze'
-                     },
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'uploads' => {
+                         'chmod' => 438,
+                         'right' => 2,
+                         'maxlength' => '2100000000000000',
+                         'path' => '/var/www/htdocs//download',
+                         'enabled' => 1
+                       },
+          'saveTranslate' => '0',
+          'size' => '16',
+          'language' => 'en',
+          'defaultAction' => 'ShowDatabases',
+          'version' => '1.1',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'news' => {
+                      'right' => 5,
+                      'captcha' => 3,
+                      'messages' => '5'
+                    },
+          'htmlright' => '2',
           'tree' => {
                       'links' => '/var/www/cgi-bin/config/links.pl',
                       'navigation' => '/var/www/cgi-bin/config/tree.pl'
                     },
-          'language' => 'en',
+          'files' => {
+                       'chmod' => '0755',
+                       'group' => 'lze',
+                       'owner' => 'lze'
+                     },
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'cgi' => {
+                     'cookiePath' => '/',
+                     'bin' => '/var/www/cgi-bin',
+                     'DocumentRoot' => '/var/www/htdocs/',
+                     'title' => 'MySQL::Admin',
+                     'style' => 'mysql',
+                     'expires' => '+1y',
+                     'serverName' => 'http://localhost'
+                   },
+          'mod' => 'n',
+          'floodtime' => 10,
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'admin' => {
+                       'password' => 'testpass'
+                     },
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
           'database' => {
+                          'CurrentDb' => 'MySQLAdmin',
                           'CurrentUser' => 'root',
                           'host' => 'localhost',
                           'password' => '',
-                          'CurrentHost' => 'localhost',
-                          'CurrentDb' => 'MySQLAdmin',
                           'user' => 'root',
-                          'name' => 'MySQLAdmin',
-                          'CurrentPass' => ''
-                        },
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'defaultAction' => 'ShowDatabases',
-          'mod' => 'n',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'news' => {
-                      'captcha' => 3,
-                      'messages' => '5',
-                      'right' => 5
-                    },
-          'version' => '1.09',
-          'floodtime' => 10,
-          'saveTranslate' => '0',
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'cgi' => {
-                     'serverName' => 'http://localhost',
-                     'style' => 'mysql',
-                     'cookiePath' => '/',
-                     'expires' => '+1y',
-                     'DocumentRoot' => '/var/www/htdocs/',
-                     'title' => 'MySQL::Admin',
-                     'bin' => '/var/www/cgi-bin'
-                   },
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'htmlright' => '2',
-          'uploads' => {
-                         'path' => '/var/www/htdocs//download',
-                         'chmod' => 438,
-                         'right' => 2,
-                         'enabled' => 1,
-                         'maxlength' => '2100000000000000'
-                       },
-          'size' => '16',
-          'admin' => {
-                       'password' => 'testpass'
-                     }
+                          'CurrentPass' => '',
+                          'CurrentHost' => 'localhost',
+                          'name' => 'MySQLAdmin'
+                        }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
